@@ -7,12 +7,12 @@ use v5.006;
 use strict;
 use version;
 
-use File::Basename      qw( basename        );
-use File::Find          qw( finddepth       );
-use File::Temp          qw( tempfile        );
-use FindBin             qw( $Bin            );
-use List::Util          qw( pairmap uniq    );
-use List::MoreUtils     qw( zip             );
+use File::Basename      qw( basename    );
+use File::Find          qw( finddepth   );
+use File::Temp          qw( tempfile    );
+use FindBin             qw( $Bin        );
+use List::Util          qw( pairmap     );
+use List::MoreUtils     qw( zip uniq    );
 
 use File::Spec::Functions
 qw
@@ -71,6 +71,9 @@ sub test_git_version
     die "Non-zero exit from git: '$?'.\n"
     if $?;
 
+    die "Empty return from 'git --version'\n"
+    unless $git;
+
     print "# git version: '$git'."
     if $verbose;
 
